@@ -36,6 +36,7 @@ SOFTWARE.
 #include "static_assert.h"
 #include "error_handler.h"
 #include "exception.h"
+#include "utility.h"
 
 #include <stdint.h>
 
@@ -71,10 +72,23 @@ namespace etl
     }
   };
 
+  //***************************************************************************
+  /// Typed storage exception.
+  //***************************************************************************
+  class typed_storage_error : public alignment_exception
+  {
+  public:
+
+    typed_storage_error(string_type file_name_, numeric_type line_number_)
+      : alignment_exception(ETL_ERROR_TEXT("typed_storage:error", ETL_ALIGNMENT_FILE_ID"B"), file_name_, line_number_)
+    {
+    }
+  };
+
   //*****************************************************************************
   /// Check that 'p' has 'required_alignment'.
   //*****************************************************************************
-  inline bool is_aligned(void* p, size_t required_alignment)
+  inline bool is_aligned(const void* p, size_t required_alignment)
   {
     uintptr_t address = reinterpret_cast<uintptr_t>(p);
     return (address % required_alignment) == 0U;
@@ -84,7 +98,7 @@ namespace etl
   /// Check that 'p' has 'Alignment'.
   //*****************************************************************************
   template <size_t Alignment>
-  bool is_aligned(void* p)
+  bool is_aligned(const void* p)
   {
     uintptr_t address = reinterpret_cast<uintptr_t>(p);
     return (address % Alignment) == 0U;
@@ -94,7 +108,7 @@ namespace etl
   /// Check that 'p' has the alignment of 'T'.
   //*****************************************************************************
   template <typename T>
-  bool is_aligned(void* p)
+  bool is_aligned(const void* p)
   {
     return is_aligned<etl::alignment_of<T>::value>(p);
   }
@@ -334,6 +348,169 @@ namespace etl
   template <size_t Length, typename T>
   using aligned_storage_as_t = typename aligned_storage_as<Length, T>::type;
 #endif
+
+  //***************************************************************************
+  /// Wrapper class that provides a memory area and lets the user create an
+  /// instance of T in this memory at runtime. This class also erases the
+  /// destructor call of T, i.e. if typed_storage goes out of scope, the
+  /// destructor if the wrapped type will not be called. This can be done
+  /// explicitly by calling destroy().
+  /// \tparam T    Type of element stored in this instance of typed_storage.
+  //***************************************************************************
+  template <typename T>
+  class typed_storage
+  {
+  public:
+
+    typedef T        value_type;
+    typedef T&       reference;
+    typedef const T& const_reference;
+    typedef T*       pointer;
+    typedef const T* const_pointer;
+
+    // Constructor
+    typed_storage()
+      : valid(false)
+    {
+    }
+
+    //***************************************************************************
+    /// Default destructor which will NOT call the destructor of the object which
+    /// was created by calling create().
+    //***************************************************************************
+    ~typed_storage()
+    {
+    }
+
+    //***************************************************************************
+    /// \returns <b>true</b> if object has been constructed using create().
+    /// \returns <b>false</b> otherwise.
+    //***************************************************************************
+    bool has_value() const
+    {
+      return valid;
+    }
+
+#if ETL_USING_CPP11
+    //***************************************************************************
+    /// Constructs the instance of T forwarding the given \p args to its constructor and
+    /// asserts if has_value() is false.
+    ///
+    /// \returns the instance of T which has been constructed in the internal byte array.
+    //***************************************************************************
+    template<typename... Args>
+    reference create(Args&&... args)
+    {
+      ETL_ASSERT(!has_value(), ETL_ERROR(etl::typed_storage_error));
+      valid = true;
+      return *::new (data.template get_address<char>()) value_type(etl::forward<Args>(args)...);
+    }
+#else
+    //***************************************************************************
+    /// Constructs the instance of T with type T1
+    /// asserts if has_value() is false.
+    ///
+    /// \returns the instance of T which has been constructed in the internal byte array.
+    //***************************************************************************
+    template<typename T1>
+    reference create(const T1& t1)
+    {
+      ETL_ASSERT(!has_value(), ETL_ERROR(etl::typed_storage_error));
+      valid = true;
+      return *::new (data.template get_address<char>()) value_type(t1);
+    }
+
+    //***************************************************************************
+    /// Constructs the instance of T with types T1, T2
+    /// asserts if has_value() is false.
+    ///
+    /// \returns the instance of T which has been constructed in the internal byte array.
+    //***************************************************************************
+    template<typename T1, typename T2>
+    reference create(const T1& t1, const T2& t2)
+    {
+      ETL_ASSERT(!has_value(), ETL_ERROR(etl::typed_storage_error));
+      valid = true;
+      return *::new (data.template get_address<char>()) value_type(t1, t2);
+    }
+
+    //***************************************************************************
+    /// Constructs the instance of T with types T1, T2, T3
+    /// asserts if has_value() is false.
+    ///
+    /// \returns the instance of T which has been constructed in the internal byte array.
+    //***************************************************************************
+    template<typename T1, typename T2, typename T3>
+    reference create(const T1& t1, const T2& t2, const T3& t3)
+    {
+      ETL_ASSERT(!has_value(), ETL_ERROR(etl::typed_storage_error));
+      valid = true;
+      return *::new (data.template get_address<char>()) value_type(t1, t2, t3);
+    }
+
+    //***************************************************************************
+    /// Constructs the instance of T with types T1, T2, T3, T4
+    /// asserts if has_value() is false.
+    ///
+    /// \returns the instance of T which has been constructed in the internal byte array.
+    //***************************************************************************
+    template<typename T1, typename T2, typename T3, typename T4>
+    reference create(const T1& t1, const T2& t2, const T3& t3, const T4& t4)
+    {
+      ETL_ASSERT(!has_value(), ETL_ERROR(etl::typed_storage_error));
+      valid = true;
+      return *::new (data.template get_address<char>()) value_type(t1, t2, t3, t4);
+    }
+#endif
+
+    //***************************************************************************
+    /// Calls the destructor of the wrapped object and asserts if has_value() is false.
+    //***************************************************************************
+    void destroy()
+    {
+      ETL_ASSERT(has_value(), ETL_ERROR(etl::typed_storage_error));
+      data.template get_reference<T>().~T();
+      valid = false;
+    }
+
+    //***************************************************************************
+    /// \returns a pointer of type T and asserts if has_value() is false.
+    //***************************************************************************
+    pointer operator->()
+    {
+      ETL_ASSERT(has_value(), ETL_ERROR(etl::typed_storage_error));
+      return data.template get_address<value_type>();
+    }
+
+    //***************************************************************************
+    /// \returns a const pointer of type T and asserts if has_value() is false.
+    //***************************************************************************
+    const_pointer operator->() const
+    {
+      return operator->();
+    }
+
+    //***************************************************************************
+    /// \returns reference of type T and asserts if has_value() is false.
+    //***************************************************************************
+    reference operator*()
+    {
+      return *operator->();
+    }
+
+    //***************************************************************************
+    /// \returns const reference of type T and asserts if has_value() is false.
+    //***************************************************************************
+    const_reference operator*() const
+    {
+      return *operator->();
+    }
+
+  private:
+
+    typename aligned_storage_as<sizeof(value_type), value_type>::type data;
+    bool valid;
+  };
 }
 
 #endif
