@@ -220,7 +220,7 @@ namespace etl
         if (timer.id != etl::timer::id::NO_TIMER)
         {
           // Has a valid period.
-          if (timer.period != etl::timer::state::INACTIVE)
+          if (timer.period != etl::timer::state::Inactive)
           {
             ++process_semaphore;
             if (timer.is_active())
@@ -297,6 +297,64 @@ namespace etl
       return false;
     }
 
+    //*******************************************
+    /// Check if there is an active timer.
+    //*******************************************
+    bool has_active_timer() const
+    {
+      ++process_semaphore;
+      bool result = !active_list.empty();
+      --process_semaphore;
+
+      return result;
+    }
+
+    //*******************************************
+    /// Get the time to the next timer event.
+    /// Returns etl::timer::interval::No_Active_Interval if there is no active timer.
+    //*******************************************
+    uint32_t time_to_next() const
+    {
+      uint32_t delta = static_cast<uint32_t>(etl::timer::interval::No_Active_Interval);
+
+      ++process_semaphore;
+      if (!active_list.empty())
+      {
+        delta = active_list.front().delta;
+      }
+      --process_semaphore;
+
+      return delta;
+    }
+
+    //*******************************************
+    /// Checks if a timer is currently active.
+    /// Returns <b>true</b> if the timer is active, otherwise <b>false</b>.
+    //*******************************************
+    bool is_active(etl::timer::id::type id_) const
+    {
+      bool result = false;
+
+      // Valid timer id?
+      if (is_valid_timer_id(id_))
+      {
+        ++process_semaphore;
+        if (has_active_timer())
+        {
+          const timer_data& timer = timer_array[id_];
+
+          // Registered timer?
+          if (timer.id != etl::timer::id::NO_TIMER)
+          {
+            result = timer.is_active();
+          }
+        }
+        --process_semaphore;
+      }
+
+      return result;
+    }
+
   protected:
 
     //*************************************************************************
@@ -307,7 +365,7 @@ namespace etl
       timer_data()
         : callback()
         , period(0U)
-        , delta(etl::timer::state::INACTIVE)
+        , delta(etl::timer::state::Inactive)
         , id(etl::timer::id::NO_TIMER)
         , previous(etl::timer::id::NO_TIMER)
         , next(etl::timer::id::NO_TIMER)
@@ -324,7 +382,7 @@ namespace etl
                  bool                 repeating_)
         : callback(callback_)
         , period(period_)
-        , delta(etl::timer::state::INACTIVE)
+        , delta(etl::timer::state::Inactive)
         , id(id_)
         , previous(etl::timer::id::NO_TIMER)
         , next(etl::timer::id::NO_TIMER)
@@ -337,7 +395,7 @@ namespace etl
       //*******************************************
       bool is_active() const
       {
-        return delta != etl::timer::state::INACTIVE;
+        return delta != etl::timer::state::Inactive;
       }
 
       //*******************************************
@@ -345,7 +403,7 @@ namespace etl
       //*******************************************
       void set_inactive()
       {
-        delta = etl::timer::state::INACTIVE;
+        delta = etl::timer::state::Inactive;
       }
 
       callback_type        callback;
@@ -378,6 +436,14 @@ namespace etl
 
   private:
 
+    //*******************************************
+    /// Check that the timer id is valid.
+    //*******************************************
+    bool is_valid_timer_id(etl::timer::id::type id_) const
+    {
+      return (id_ < MAX_TIMERS);
+    }
+
     //*************************************************************************
     /// A specialised intrusive linked list for timer data.
     //*************************************************************************
@@ -500,7 +566,7 @@ namespace etl
 
         timer.previous = etl::timer::id::NO_TIMER;
         timer.next = etl::timer::id::NO_TIMER;
-        timer.delta = etl::timer::state::INACTIVE;
+        timer.delta = etl::timer::state::Inactive;
       }
 
       //*******************************
@@ -509,6 +575,12 @@ namespace etl
         return ptimers[head];
       }
 
+      //*******************************
+      const timer_data& front() const
+      {
+        return ptimers[head];
+      }
+
       //*******************************
       etl::timer::id::type begin()
       {
@@ -563,7 +635,7 @@ namespace etl
     timer_list active_list;
 
     bool enabled;
-    TSemaphore process_semaphore;
+    mutable TSemaphore process_semaphore;
     uint_least8_t number_of_registered_timers;
 
   public:
