@@ -352,7 +352,7 @@ namespace etl
     etl::ipool* p_node_pool;    ///< The pool of data nodes used in the list.
     size_type   MAX_SIZE;       ///< The maximum size of the forward_list.
     bool        pool_is_shared; ///< If <b>true</b> then the pool is shared between lists.
-    ETL_DECLARE_DEBUG_COUNT     ///< Internal debugging.
+    ETL_DECLARE_DEBUG_COUNT;     ///< Internal debugging.
   };
 
   //***************************************************************************
@@ -717,7 +717,7 @@ namespace etl
     }
 #endif
 
-#if ETL_USING_CPP11 && ETL_NOT_USING_STLPORT
+#if ETL_USING_CPP11 && ETL_NOT_USING_STLPORT && !defined(ETL_FORWARD_LIST_FORCE_CPP03_IMPLEMENTATION)
     //*************************************************************************
     /// Emplaces a value to the front of the list..
     //*************************************************************************
@@ -729,11 +729,26 @@ namespace etl
 #endif
       data_node_t* p_data_node = allocate_data_node();
       ::new (&(p_data_node->value)) T(etl::forward<Args>(args)...);
-      ETL_INCREMENT_DEBUG_COUNT
+      ETL_INCREMENT_DEBUG_COUNT;
       insert_node_after(start_node, *p_data_node);
       return front();
     }
 #else
+    //*************************************************************************
+    /// Emplaces a value to the front of the list..
+    //*************************************************************************
+    reference emplace_front()
+    {
+#if defined(ETL_CHECK_PUSH_POP)
+      ETL_ASSERT(!full(), ETL_ERROR(forward_list_full));
+#endif
+      data_node_t* p_data_node = allocate_data_node();
+      ::new (&(p_data_node->value)) T();
+      ETL_INCREMENT_DEBUG_COUNT;
+        insert_node_after(start_node, *p_data_node);
+      return front();
+    }
+
     //*************************************************************************
     /// Emplaces a value to the front of the list..
     //*************************************************************************
@@ -745,7 +760,7 @@ namespace etl
 #endif
       data_node_t* p_data_node = allocate_data_node();
       ::new (&(p_data_node->value)) T(value1);
-      ETL_INCREMENT_DEBUG_COUNT
+      ETL_INCREMENT_DEBUG_COUNT;
       insert_node_after(start_node, *p_data_node);
       return front();
     }
@@ -761,7 +776,7 @@ namespace etl
 #endif
       data_node_t* p_data_node = allocate_data_node();
       ::new (&(p_data_node->value)) T(value1, value2);
-      ETL_INCREMENT_DEBUG_COUNT
+      ETL_INCREMENT_DEBUG_COUNT;
       insert_node_after(start_node, *p_data_node);
       return front();
     }
@@ -777,7 +792,7 @@ namespace etl
 #endif
       data_node_t* p_data_node = allocate_data_node();
       ::new (&(p_data_node->value)) T(value1, value2, value3);
-      ETL_INCREMENT_DEBUG_COUNT
+      ETL_INCREMENT_DEBUG_COUNT;
       insert_node_after(start_node, *p_data_node);
       return front();
     }
@@ -793,7 +808,7 @@ namespace etl
 #endif
       data_node_t* p_data_node = allocate_data_node();
       ::new (&(p_data_node->value)) T(value1, value2, value3, value4);
-      ETL_INCREMENT_DEBUG_COUNT
+      ETL_INCREMENT_DEBUG_COUNT;
       insert_node_after(start_node, *p_data_node);
       return front();
     }
@@ -879,7 +894,7 @@ namespace etl
       return iterator(&data_node);
     }
 
-#if ETL_USING_CPP11 && ETL_NOT_USING_STLPORT
+#if ETL_USING_CPP11 && ETL_NOT_USING_STLPORT && !defined(ETL_FORWARD_LIST_FORCE_CPP03_IMPLEMENTATION)
     //*************************************************************************
     /// Emplaces a value to the forward_list after the specified position.
     //*************************************************************************
@@ -890,12 +905,27 @@ namespace etl
 
       data_node_t* p_data_node = allocate_data_node();
       ::new (&(p_data_node->value)) T(etl::forward<Args>(args)...);
-      ETL_INCREMENT_DEBUG_COUNT
+      ETL_INCREMENT_DEBUG_COUNT;
       insert_node_after(*to_iterator(position).p_node, *p_data_node);
 
       return iterator(p_data_node);
     }
 #else
+    //*************************************************************************
+    /// Emplaces a value to the forward_list after the specified position.
+    //*************************************************************************
+    iterator emplace_after(const_iterator position)
+    {
+      ETL_ASSERT(!full(), ETL_ERROR(forward_list_full));
+
+      data_node_t* p_data_node = allocate_data_node();
+      ::new (&(p_data_node->value)) T();
+      ETL_INCREMENT_DEBUG_COUNT;
+      insert_node_after(*to_iterator(position).p_node, *p_data_node);
+
+      return iterator(p_data_node);
+    }
+
     //*************************************************************************
     /// Emplaces a value to the forward_list after the specified position.
     //*************************************************************************
@@ -906,8 +936,8 @@ namespace etl
 
       data_node_t* p_data_node = allocate_data_node();
       ::new (&(p_data_node->value)) T(value1);
-      ETL_INCREMENT_DEBUG_COUNT
-      insert_node_after(*position.p_node, *p_data_node);
+      ETL_INCREMENT_DEBUG_COUNT;
+      insert_node_after(*to_iterator(position).p_node, *p_data_node);
 
       return iterator(p_data_node);
     }
@@ -922,8 +952,8 @@ namespace etl
 
       data_node_t* p_data_node = allocate_data_node();
       ::new (&(p_data_node->value)) T(value1, value2);
-      ETL_INCREMENT_DEBUG_COUNT
-      insert_node_after(*position.p_node, *p_data_node);
+      ETL_INCREMENT_DEBUG_COUNT;
+      insert_node_after(*to_iterator(position).p_node, *p_data_node);
 
       return iterator(p_data_node);
     }
@@ -938,8 +968,8 @@ namespace etl
 
       data_node_t* p_data_node = allocate_data_node();
       ::new (&(p_data_node->value)) T(value1, value2, value3);
-      ETL_INCREMENT_DEBUG_COUNT
-      insert_node_after(*position.p_node, *p_data_node);
+      ETL_INCREMENT_DEBUG_COUNT;
+      insert_node_after(*to_iterator(position).p_node, *p_data_node);
 
       return iterator(p_data_node);
     }
@@ -954,8 +984,8 @@ namespace etl
 
       data_node_t* p_data_node = allocate_data_node();
       ::new (&(p_data_node->value)) T(value1, value2, value3, value4);
-      ETL_INCREMENT_DEBUG_COUNT
-      insert_node_after(*position.p_node, *p_data_node);
+      ETL_INCREMENT_DEBUG_COUNT;
+      insert_node_after(*to_iterator(position).p_node, *p_data_node);
 
       return iterator(p_data_node);
     }
@@ -1432,7 +1462,7 @@ namespace etl
         {
           ETL_ASSERT(p_node_pool != ETL_NULLPTR, ETL_ERROR(forward_list_no_pool));
           p_node_pool->release_all();
-          ETL_RESET_DEBUG_COUNT
+          ETL_RESET_DEBUG_COUNT;
         }
         else
         {
@@ -1459,7 +1489,7 @@ namespace etl
     {
       data_node_t* p_node = allocate_data_node();
       ::new (&(p_node->value)) T(value);
-      ETL_INCREMENT_DEBUG_COUNT
+      ETL_INCREMENT_DEBUG_COUNT;
 
       return *p_node;
     }
@@ -1472,7 +1502,7 @@ namespace etl
     {
       data_node_t* p_node = allocate_data_node();
       ::new (&(p_node->value)) T(etl::move(value));
-      ETL_INCREMENT_DEBUG_COUNT
+      ETL_INCREMENT_DEBUG_COUNT;
 
       return *p_node;
     }
@@ -1595,7 +1625,7 @@ namespace etl
     {
       node.value.~T();
       p_node_pool->release(&node);
-      ETL_DECREMENT_DEBUG_COUNT
+      ETL_DECREMENT_DEBUG_COUNT;
     }
 
     // Disable copy construction.
@@ -1766,7 +1796,7 @@ namespace etl
   template <typename... T>
   constexpr auto make_forward_list(T&&... t) -> etl::forward_list<typename etl::common_type_t<T...>, sizeof...(T)>
   {
-    return { { etl::forward<T>(t)... } };
+    return { etl::forward<T>(t)... };
   }
 #endif
 
