@@ -86,7 +86,7 @@ namespace etl
   public:
 
     flat_multiset_iterator(string_type file_name_, numeric_type line_number_)
-      : flat_multiset_exception(ETL_ERROR_TEXT("flat_multiset:iterator", ETL_REFERENCE_FLAT_MULTISET_FILE_ID"C"), file_name_, line_number_)
+      : flat_multiset_exception(ETL_ERROR_TEXT("flat_multiset:iterator", ETL_REFERENCE_FLAT_MULTISET_FILE_ID"B"), file_name_, line_number_)
     {
     }
   };
