@@ -48,7 +48,7 @@ namespace etl
   {
     inline namespace string_literals
     {
-      constexpr etl::string_view operator ""_sv(const char* str, size_t length) noexcept
+      inline constexpr etl::string_view operator ""_sv(const char* str, size_t length) noexcept
       {
         return etl::string_view{ str, length };
       }
@@ -92,6 +92,7 @@ namespace etl
     string(const etl::string<MAX_SIZE_>& other)
       : istring(reinterpret_cast<value_type*>(&buffer), MAX_SIZE)
     {
+      this->initialise();
       this->assign(other);
     }
 
@@ -102,6 +103,7 @@ namespace etl
     string(const etl::istring& other)
       : istring(reinterpret_cast<value_type*>(&buffer), MAX_SIZE)
     {
+      this->initialise();
       this->assign(other);
     }
 
@@ -116,6 +118,7 @@ namespace etl
     {
       ETL_ASSERT(position < other.size(), ETL_ERROR(string_out_of_bounds));
 
+      this->initialise();
       this->assign(other, position, length);
     }
 
@@ -126,7 +129,8 @@ namespace etl
     ETL_EXPLICIT_STRING_FROM_CHAR string(const value_type* text)
       : istring(reinterpret_cast<value_type*>(&buffer), MAX_SIZE)
     {
-      this->assign(text, text + etl::char_traits<value_type>::length(text));
+      this->initialise();
+      this->assign(text);
     }
 
     //*************************************************************************
@@ -137,6 +141,7 @@ namespace etl
     string(const value_type* text, size_t count)
       : istring(reinterpret_cast<value_type*>(&buffer), MAX_SIZE)
     {
+      this->initialise();
       this->assign(text, text + count);
     }
 
@@ -162,6 +167,7 @@ namespace etl
     string(TIterator first, TIterator last, typename etl::enable_if<!etl::is_integral<TIterator>::value, int>::type = 0)
       : istring(reinterpret_cast<value_type*>(&buffer), MAX_SIZE)
     {
+      this->initialise();
       this->assign(first, last);
     }
 
@@ -172,6 +178,7 @@ namespace etl
     string(std::initializer_list<value_type> init)
       : istring(reinterpret_cast<value_type*>(&buffer), MAX_SIZE)
     {
+      this->initialise();
       this->assign(init.begin(), init.end());
     }
 #endif
@@ -183,6 +190,7 @@ namespace etl
     explicit string(const etl::string_view& view)
       : istring(reinterpret_cast<value_type*>(&buffer), MAX_SIZE)
     {
+      this->initialise();
       this->assign(view.begin(), view.end());
     }
 
@@ -304,6 +312,7 @@ namespace etl
     string_ext(const etl::string_ext& other, value_type* buffer, size_type buffer_size)
       : istring(buffer, buffer_size - 1U)
     {
+      this->initialise();
       this->assign(other);
     }
 
@@ -314,6 +323,7 @@ namespace etl
     string_ext(const etl::istring& other, value_type* buffer, size_type buffer_size)
       : istring(buffer, buffer_size - 1U)
     {
+      this->initialise();
       this->assign(other);
     }
 
@@ -328,6 +338,7 @@ namespace etl
     {
       ETL_ASSERT(position < other.size(), ETL_ERROR(string_out_of_bounds));
 
+      this->initialise();
       this->assign(other, position, length);
     }
 
@@ -345,6 +356,7 @@ namespace etl
       }
       else
       {
+        this->initialise();
         this->assign(text, text + etl::strlen(text));
       }
     }
@@ -357,6 +369,7 @@ namespace etl
     string_ext(const value_type* text, size_type count, value_type* buffer, size_type buffer_size)
       : istring(buffer, buffer_size - 1U)
     {
+      this->initialise();
       this->assign(text, text + count);
     }
 
