@@ -49,7 +49,7 @@ namespace etl
   {
     inline namespace string_literals
     {
-      constexpr etl::u8string_view operator ""_sv(const char8_t* str, size_t length) noexcept
+      inline constexpr etl::u8string_view operator ""_sv(const char8_t* str, size_t length) noexcept
       {
         return etl::u8string_view{ str, length };
       }
@@ -92,6 +92,7 @@ namespace etl
     u8string(const etl::u8string<MAX_SIZE_>& other)
       : iu8string(reinterpret_cast<value_type*>(&buffer), MAX_SIZE)
     {
+      this->initialise();
       this->assign(other);
     }
 
@@ -102,6 +103,7 @@ namespace etl
     u8string(const etl::iu8string& other)
       : iu8string(reinterpret_cast<value_type*>(&buffer), MAX_SIZE)
     {
+      this->initialise();
       this->assign(other);
     }
 
@@ -116,6 +118,7 @@ namespace etl
     {
       ETL_ASSERT(position < other.size(), ETL_ERROR(string_out_of_bounds));
 
+      this->initialise();
       this->assign(other, position, length);
     }
 
@@ -126,7 +129,8 @@ namespace etl
     ETL_EXPLICIT_STRING_FROM_CHAR u8string(const value_type* text)
       : iu8string(reinterpret_cast<value_type*>(&buffer), MAX_SIZE)
     {
-      this->assign(text, text + etl::char_traits<value_type>::length(text));
+      this->initialise();
+      this->assign(text);
     }
 
     //*************************************************************************
@@ -137,6 +141,7 @@ namespace etl
     u8string(const value_type* text, size_t count)
       : iu8string(reinterpret_cast<value_type*>(&buffer), MAX_SIZE)
     {
+      this->initialise();
       this->assign(text, text + count);
     }
 
@@ -162,6 +167,7 @@ namespace etl
     u8string(TIterator first, TIterator last, typename etl::enable_if<!etl::is_integral<TIterator>::value, int>::type = 0)
       : iu8string(reinterpret_cast<value_type*>(&buffer), MAX_SIZE)
     {
+      this->initialise();
       this->assign(first, last);
     }
 
@@ -172,6 +178,7 @@ namespace etl
     u8string(std::initializer_list<value_type> init)
       : iu8string(reinterpret_cast<value_type*>(&buffer), MAX_SIZE)
     {
+      this->initialise();
       this->assign(init.begin(), init.end());
     }
 #endif
@@ -183,6 +190,7 @@ namespace etl
     explicit u8string(const etl::u8string_view& view)
       : iu8string(reinterpret_cast<value_type*>(&buffer), MAX_SIZE)
     {
+      this->initialise();
       this->assign(view.begin(), view.end());
     }
 
@@ -304,6 +312,7 @@ namespace etl
     u8string_ext(const etl::u8string_ext& other, value_type* buffer, size_type buffer_size)
       : iu8string(buffer, buffer_size - 1U)
     {
+      this->initialise();
       this->assign(other);
     }
 
@@ -314,6 +323,7 @@ namespace etl
     u8string_ext(const etl::iu8string& other, value_type* buffer, size_type buffer_size)
       : iu8string(buffer, buffer_size - 1U)
     {
+      this->initialise();
       this->assign(other);
     }
 
@@ -328,6 +338,7 @@ namespace etl
     {
       ETL_ASSERT(position < other.size(), ETL_ERROR(string_out_of_bounds));
 
+      this->initialise();
       this->assign(other, position, length);
     }
 
@@ -345,6 +356,7 @@ namespace etl
       }
       else
       {
+        this->initialise();
         this->assign(text, text + etl::strlen(text));
       }
     }
@@ -357,6 +369,7 @@ namespace etl
     u8string_ext(const value_type* text, size_type count, value_type* buffer, size_type buffer_size)
       : iu8string(buffer, buffer_size - 1U)
     {
+      this->initialise();
       this->assign(text, text + count);
     }
 
@@ -382,6 +395,7 @@ namespace etl
     u8string_ext(TIterator first, TIterator last, value_type* buffer, size_type buffer_size, typename etl::enable_if<!etl::is_integral<TIterator>::value, int>::type = 0)
       : iu8string(buffer, buffer_size - 1U)
     {
+      this->initialise();
       this->assign(first, last);
     }
 
@@ -392,6 +406,7 @@ namespace etl
     u8string_ext(std::initializer_list<value_type> init, value_type* buffer, size_type buffer_size)
       : iu8string(buffer, buffer_size - 1U)
     {
+      this->initialise();
       this->assign(init.begin(), init.end());
     }
 #endif
@@ -403,6 +418,7 @@ namespace etl
     explicit u8string_ext(const etl::u8string_view& view, value_type* buffer, size_type buffer_size)
       : iu8string(buffer, buffer_size - 1U)
     {
+      this->initialise();
       this->assign(view.begin(), view.end());
     }
 
