@@ -96,6 +96,7 @@ SOFTWARE.
   #define ETL_MESSAGE_ROUTER_FORCE_CPP03_IMPLEMENTATION
   #define ETL_FSM_FORCE_CPP03_IMPLEMENTATION
   //#define ETL_DELEGATE_FORCE_CPP03_IMPLEMENTATION // C++03 implementation is tested at the same time as the C++11 and above.
+  #define ETL_CLOSURE_FORCE_CPP03_IMPLEMENTATION
   #define ETL_SINGLETON_FORCE_CPP03_IMPLEMENTATION
   #define ETL_BYTE_FORCE_CPP03_IMPLEMENTATION
   #define ETL_LIST_FORCE_CPP03_IMPLEMENTATION
@@ -120,6 +121,14 @@ SOFTWARE.
   #endif
 #endif
 
+#define ETL_CHRONO_SYSTEM_CLOCK_DURATION          etl::chrono::milliseconds
+#define ETL_CHRONO_HIGH_RESOLUTION_CLOCK_DURATION etl::chrono::nanoseconds
+#define ETL_CHRONO_STEADY_CLOCK_DURATION          etl::chrono::seconds
+
+#define ETL_CHRONO_SYSTEM_CLOCK_IS_STEADY false
+
+#define ETL_USE_VERBOSE_CHRONO_LITERALS 
+
 #if defined(ETL_DEVELOPMENT_OS_WINDOWS)
   #define ETL_TARGET_OS_WINDOWS
 #elif defined(ETL_DEVELOPMENT_OS_LINUX)
