@@ -253,6 +253,77 @@ namespace
     int sender_id;
   };
 
+  //***************************************************************************
+  // Router that handles messages 1, 2, 3.
+  // 'receive' is overridden.
+  //***************************************************************************
+  class Router3 : public etl::message_router<Router3, Message1, Message2, Message3>
+  {
+  public:
+
+    using base = etl::message_router<Router3, Message1, Message2, Message3>;
+
+    Router3()
+      : message_router(ROUTER3)
+      , message1_received(false)
+      , message2_received(false)
+      , message3_received(false)
+      , unknown_message_received(false)
+    {
+    }
+
+    void receive(const etl::imessage& msg) override
+    {
+      switch (msg.get_message_id())
+      {
+        case MESSAGE1:
+        {
+          message1_received = true;
+          break;
+        }
+
+        case MESSAGE2:
+        {
+          message2_received = true;
+          break;
+        }
+
+        case MESSAGE3:
+        {
+          message3_received = true;
+          break;
+        }
+
+        default:
+        {
+          unknown_message_received = true;
+          break;
+        }
+      }
+    }
+
+    void on_receive(const Message1&)
+    {
+    }
+
+    void on_receive(const Message2&)
+    {
+    }
+
+    void on_receive(const Message3&)
+    {
+    }
+
+    void on_receive_unknown(const etl::imessage&)
+    {
+    }
+
+    bool message1_received;
+    bool message2_received;
+    bool message3_received;
+    bool unknown_message_received;
+  };
+
   etl::imessage_router* p_router;
 
   SUITE(test_message_router)
@@ -641,5 +712,26 @@ namespace
       CHECK_EQUAL(0, r1.message4_count);
       CHECK_EQUAL(0, r1.message_unknown_count);
     }
+
+    //*************************************************************************
+    TEST(message_router_with_overloaded_receive)
+    {
+      Router3 router;
+
+      Message1 message1(router);
+      Message2 message2(router);
+      Message3 message3(router);
+
+      router.receive(message1);
+      CHECK_TRUE(router.message1_received);
+
+      router.receive(message2);
+      CHECK_TRUE(router.message2_received);
+
+      router.receive(message3);
+      CHECK_TRUE(router.message3_received);
+
+      CHECK_FALSE(router.unknown_message_received);
+    }
   };
 }
