@@ -157,6 +157,16 @@ namespace
       CHECK_EQUAL(0, int(result.value()));
     }
 
+    //*************************************************************************
+    TEST(test_emplace_return)
+    {
+      etl::optional<DataM> data;
+
+      DataM* datam = &data.emplace(1U);
+      CHECK_EQUAL(datam, &data.value());
+      CHECK(datam != nullptr);
+    }
+
     //*************************************************************************
     TEST(test_moveable)
     {
