@@ -30,6 +30,7 @@ SOFTWARE.
 
 #include "etl/span.h"
 #include "etl/array.h"
+#include "etl/unaligned_type.h"
 
 #include <array>
 #include <vector>
@@ -1166,6 +1167,99 @@ namespace
       }
     }
 
+    //*************************************************************************
+    TEST(test_span_issue_1050_questions_on_span_constructors)
+    {
+      int arr[5]{};
+      etl::span<int, 5> span1(arr);
+      etl::span<int, 5> span2(span1);
+      //etl::span<int, 10> span3(span1); // This line should fail to compile.
+    }
+    
+    //*************************************************************************
+    TEST(test_reinterpret_as)
+    {
+      uint8_t data[] = { 0x01, 0x02, 0x03, 0x04, 0x05 };
+      etl::span<uint8_t, 5> data0 = data;
+
+      etl::span<etl::be_uint16_t> data1 = data0.reinterpret_as<etl::be_uint16_t>();
+
+      CHECK_EQUAL(data1.size(), 2);
+      CHECK(data1[0] == 0x102);
+      CHECK(data1[1] == 0x304);
+    }
+
+    //*************************************************************************
+    TEST(test_reinterpret_as_aligned)
+    {
+      uint32_t data[] = { 0x01020304, 0x020406080, 0x03400560};
+      etl::span<uint32_t, 3> data0 = data;
+      CHECK_EQUAL(data0.size(), 3);
+
+      etl::span<uint8_t> data1 = data0.reinterpret_as<uint8_t>();
+      CHECK_EQUAL(data1.size(), 12);
+
+      etl::span<uint16_t> data2 = data1.subspan(2).reinterpret_as<uint16_t>();
+      CHECK_EQUAL(data2.size(), 5);
+
+      CHECK_THROW(data2 = data1.subspan(1).reinterpret_as<uint16_t>(), etl::span_alignment_exception);
+    }
+
+    //*************************************************************************
+    TEST(test_copy)
+    {
+      uint8_t src[] = { 0x01, 0x02, 0x03, 0x04, 0x05 };
+      uint8_t dst[] = { 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
+      {
+        etl::span<uint8_t, 5> data0 = src;
+        etl::span<uint8_t, 6> data1 = dst;
+
+        CHECK_EQUAL(etl::copy(data0, data1), true);
+        CHECK(std::equal(data0.begin(), data0.end(), data1.begin()));
+      }
+      {
+        etl::span<uint8_t, 5> data0 = src;
+        etl::span<uint8_t, 5> data1(&dst[1], 5);
+
+        CHECK_EQUAL(etl::copy(data0, data1), true);
+        CHECK(std::equal(data0.begin(), data0.end(), data1.begin()));
+      }
+
+      {
+        etl::span<uint8_t, 5> data0 = src;
+        etl::span<uint8_t, 4> data1(&dst[2], 4);
+
+        CHECK_EQUAL(etl::copy(data0, data1), false);
+      }
+      {
+        etl::span<uint8_t, 0> data0(&src[0], 0);
+        etl::span<uint8_t, 6> data1 = dst;
+
+        CHECK_EQUAL(etl::copy(data0, data1), true);
+      }
+      {
+        etl::span<uint8_t, 5> data0 = src;
+        etl::span<uint8_t, 5> data1 = src;
+
+        CHECK_EQUAL(etl::copy(data0, data1), true);
+      }
+    }
+
+    //*************************************************************************
+    TEST(test_dynamic_span_to_fixed_span)
+    {
+      int data[5] = { 0, 1, 2, 3, 4 };
+      etl::span<int> sp1(data);
+
+      using span_4 = etl::span<int, 4>;
+      using span_5 = etl::span<int, 5>;
+      using span_8 = etl::span<int, 8>;
+
+      CHECK_NO_THROW({ span_5 sp2(sp1); });
+      CHECK_THROW({ span_4 sp3(sp1); }, etl::span_size_mismatch);
+      CHECK_THROW({ span_8 sp4(sp1); }, etl::span_size_mismatch);
+    }
+
 #include "etl/private/diagnostic_pop.h"
   };
 }
